pub struct SettlementFailureReason { /* private fields */ }Expand description
Bounded failure reason safe for durable storage and telemetry labels.
Implementations
Sourceimpl SettlementFailureReason
impl SettlementFailureReason
Sourcepub fn from_detail(
code: SettlementFailureCode,
detail: impl AsRef<[u8]>,
) -> Self
pub fn from_detail( code: SettlementFailureCode, detail: impl AsRef<[u8]>, ) -> Self
Hash an unbounded failure detail into its durable representation.
Sourcepub const fn from_digest(
code: SettlementFailureCode,
detail_sha256: [u8; 32],
) -> Self
pub const fn from_digest( code: SettlementFailureCode, detail_sha256: [u8; 32], ) -> Self
Restore a reason from a persisted digest.
Sourcepub const fn code(&self) -> SettlementFailureCode
pub const fn code(&self) -> SettlementFailureCode
Return the bounded failure code.
Sourcepub const fn detail_sha256(&self) -> &[u8; 32]
pub const fn detail_sha256(&self) -> &[u8; 32]
Return the SHA-256 digest of the original detail.
Sourcepub const fn effective_class(
&self,
requested: SettlementFailureClass,
) -> SettlementFailureClass
pub const fn effective_class( &self, requested: SettlementFailureClass, ) -> SettlementFailureClass
Enforce the retry disposition permitted by this failure code.